build-mingw-w64: Use silent rules for compiling things

This reduces the amount of log output significantly.

For the linux build on github actions, this reduces the log output
from 8.5 MB down to 4.7 MB.
This commit is contained in:
Martin Storsjö committed 2025-04-17 23:34:40 +03:00
1 parent eeb12404b5
commit 20099b94e6
3 files changed
+4

No files matched your search

+1
View File
@@ -64,6 +64,7 @@ for lib in winpthreads winstorecompat; do
cd build-$arch
arch_prefix="$PREFIX/$arch-w64-mingw32"
../configure --host=$arch-w64-mingw32 --prefix="$arch_prefix" --libdir="$arch_prefix/lib" \
--enable-silent-rules \
CFLAGS="$USE_CFLAGS" \
CXXFLAGS="$USE_CFLAGS"
$MAKE -j$CORES
+2
View File
@@ -104,6 +104,8 @@ else
fi
ANY_ARCH=$(echo $ARCHS | awk '{print $1}')
CONFIGFLAGS="$CONFIGFLAGS --enable-silent-rules"
cd mingw-w64-tools/gendef
[ -z "$CLEAN" ] || rm -rf build${CROSS_NAME}
mkdir -p build${CROSS_NAME}
+1
View File
@@ -132,6 +132,7 @@ for arch in $ARCHS; do
;;
esac
FLAGS="$FLAGS --with-default-msvcrt=$DEFAULT_MSVCRT"
FLAGS="$FLAGS --enable-silent-rules"
../configure --host=$arch-w64-mingw32 --prefix="$PREFIX/$arch-w64-mingw32" $FLAGS $CFGUARD_FLAGS $CRT_CONFIG_FLAGS
$MAKE -j$CORES
$MAKE install